@@ -5,8 +5,8 @@ import matplotlib.pyplot as plt
 import numpy as np
 
 from ibllib.ephys.neuropixel import SITES_COORDINATES
-from oneibl.one import ONE
-import alf.io
+from one.api import ONE
+import one.alf.io as alfio
 import ibllib.atlas as atlas
 from ibllib.ephys.spikes import probes_description as extract_probes
 from ibllib.dsp.utils import fcn_cosine
@@ -63,10 +63,10 @@ def get_micro_manipulator_data(subject, one=None, force_extract=False):
     and task settings file.
     """
     if not one:
-        one = ONE()
+        one = ONE(cache_rest=None)
 
     eids, sessions = one.search(subject=subject, task_protocol='ephys', details=True)
-    probes = alf.io.AlfBunch({})
+    probes = alfio.AlfBunch({})
     for ses in sessions:
         sess_path = Path(ses['local_path'])
         probe = None
@@ -81,7 +81,7 @@ def get_micro_manipulator_data(subject, one=None, force_extract=False):
                                 f" {ses['local_path']}. Skip this session.")
                 continue
             extract_probes(sess_path, bin_exists=False)
-            probe = alf.io.load_object(sess_path.joinpath('alf'), 'probes')
+            probe = alfio.load_object(sess_path.joinpath('alf'), 'probes')
         one.load(ses['url'], dataset_types='channels.localCoordinates', download_only=True)
         # get for each insertion the sites local mapping: if not found assumes checkerboard pattern
         probe['sites_coordinates'] = []
@@ -233,7 +233,7 @@ def register_track(probe_id, picks=None, one=None, overwrite=False, channels=Tru
         hist_qc = base.QC(probe_id, one=one, endpoint='insertions')
         hist_qc.update_extended_qc({'tracing_exists': False})
         hist_qc.update('CRITICAL', namespace='tracing')
-
+        insertion_histology = None
         # Here need to change the track qc to critical and also extended qc to zero
     else:
         brain_locations, insertion_histology = get_brain_regions(picks)
@@ -247,9 +247,9 @@ def register_track(probe_id, picks=None, one=None, overwrite=False, channels=Tru
         # 2) patch or create the trajectory coming from histology track
         tdict = create_trajectory_dict(probe_id, insertion_histology, provenance='Histology track')
 
-    hist_traj = one.alyx.rest('trajectories', 'list',
-                              probe_insertion=probe_id,
-                              provenance='Histology track')
+    hist_traj = one.alyx.get('/trajectories?'
+                             f'&probe_insertion={probe_id}'
+                             '&provenance=Histology track', clobber=True)
     # if the trajectory exists, remove it, this will cascade delete existing channel locations
     if len(hist_traj):
         if overwrite:
@@ -286,7 +286,8 @@ def register_aligned_track(probe_id, xyz_channels, chn_coords=None, one=None, ov
 
     hist_traj = one.alyx.rest('trajectories', 'list',
                               probe_insertion=probe_id,
-                              provenance='Ephys aligned histology track')
+                              provenance='Ephys aligned histology track',
+                              no_cache=True)
     # if the trajectory exists, remove it, this will cascade delete existing channel locations
     if len(hist_traj):
         if overwrite:
@@ -393,7 +394,7 @@ def register_track_files(path_tracks, one=None, overwrite=False):
         # beware: there may be underscores in the subject nickname
 
         search_filter = _parse_filename(track_file)
-        probe = one.alyx.rest('insertions', 'list', **search_filter)
+        probe = one.alyx.rest('insertions', 'list', no_cache=True, **search_filter)
         if len(probe) == 0:
             eid = one.search(subject=search_filter['subject'], date_range=search_filter['date'],
                              number=search_filter['experiment_number'])
@@ -448,9 +449,9 @@ def detect_missing_histology_tracks(path_tracks=None, one=None, subject=None):
         return
 
     for subj in unique_subjects:
-        insertions = one.alyx.rest('insertions', 'list', subject=subj)
+        insertions = one.alyx.rest('insertions', 'list', subject=subj, no_cache=True)
         trajectories = one.alyx.rest('trajectories', 'list', subject=subj,
-                                     provenance='Histology track')
+                                     provenance='Histology track', no_cache=True)
         if len(insertions) != len(trajectories):
             ins_sess = np.array([ins['session'] + ins['name'] for ins in insertions])
             traj_sess = np.array([traj['session']['id'] + traj['probe_name']
@@ -459,7 +460,7 @@ def detect_missing_histology_tracks(path_tracks=None, one=None, subject=None):
 
             for idx in miss_idx:
 
-                info = one.path_from_eid(ins_sess[idx][:36]).parts
+                info = one.eid2path(ins_sess[idx][:36], query_type='remote').parts
                 print(ins_sess[idx][:36])
                 msg = f"Histology tracing missing for {info[-3]}, {info[-2]}, {info[-1]}," \
                       f" {ins_sess[idx][36:]}.\nEnter [y]es to register an empty track for " \
