@@ -1,4 +1,5 @@
 import abc
+import warnings
 import concurrent.futures
 import json
 import logging
@@ -10,6 +11,7 @@ from pathlib import Path, PurePath
 import shutil
 from typing import Any, Sequence, Union, Optional, List, Dict
 from uuid import UUID
+from pprint import pprint
 
 import requests
 import tqdm
@@ -24,13 +26,14 @@ from alf.files import is_valid, alf_parts
 from ibllib.exceptions import \
     ALFMultipleObjectsFound, ALFObjectNotFound, ALFMultipleCollectionsFound
 from ibllib.io import hashfile, spikeglx
-from ibllib.misc import pprint
 from oneibl.dataclass import SessionDataInfo
 from brainbox.io import parquet
 from brainbox.numerical import ismember, ismember2d, find_first_2d
 
 _logger = logging.getLogger('ibllib')
 
+warnings.warn('Use `import one` instead of `import oneibl`', DeprecationWarning)
+
 
 def Listable(t): return Union[t, Sequence[t]]  # noqa
 
@@ -996,6 +999,9 @@ class OneAlyx(OneAbstract):
             parquet.save(self._cache_file, self._cache)
 
     def download_raw_partial(self, url_cbin, url_ch, first_chunk=0, last_chunk=0):
+        import warnings
+        warnings.warn('This function has been moved to ibllib.io.spikeglx', DeprecationWarning)
+
         assert str(url_cbin).endswith('.cbin')
         assert str(url_ch).endswith('.ch')
 
@@ -1028,7 +1034,7 @@ class OneAlyx(OneAbstract):
                 cmeta_stream = json.load(f)
             if (cmeta_stream.get('chopped_first_sample', None) == i0 and
                     cmeta_stream.get('chopped_total_samples', None) == ns_stream):
-                return spikeglx.Reader(ch_file_stream.with_suffix('.cbin'))
+                return spikeglx.Reader(ch_file_stream.with_suffix('.cbin'), open=True)
         else:
             shutil.copy(ch_file, ch_file_stream)
         assert ch_file_stream.exists()
@@ -1066,13 +1072,13 @@ class OneAlyx(OneAbstract):
             chunks=(first_byte, n_bytes))
         cbin_local_path = alfio.remove_uuid_file(cbin_local_path)
         cbin_local_path_renamed = cbin_local_path.with_suffix('.stream.cbin')
-        cbin_local_path.rename(cbin_local_path_renamed)
+        cbin_local_path.replace(cbin_local_path_renamed)
         assert cbin_local_path_renamed.exists()
 
         shutil.copy(cbin_local_path.with_suffix('.meta'),
                     cbin_local_path_renamed.with_suffix('.meta'))
-        reader = spikeglx.Reader(cbin_local_path_renamed)
-        return reader
+
+        return spikeglx.Reader(cbin_local_path_renamed, open=True)
 
 
 def _validate_date_range(date_range):
