@@ -1,12 +1,5 @@
-# -*- coding: utf-8 -*-
-
 """ONE light."""
 
-
-# -------------------------------------------------------------------------------------------------
-# Imports
-# -------------------------------------------------------------------------------------------------
-
 import csv
 from collections import defaultdict
 from ftplib import FTP, error_perm
@@ -20,6 +13,7 @@ import re
 import sys
 import tempfile
 import urllib.parse
+import warnings
 
 import click
 import requests
@@ -29,6 +23,8 @@ import alf.io
 
 logger = logging.getLogger(__name__)
 
+warnings.warn('`oneibl.onelight` will be removed in future version', DeprecationWarning)
+
 
 # -------------------------------------------------------------------------------------------------
 # Logging
