@@ -7,15 +7,16 @@ import ibllib.io.extractors.base
 from dateutil import parser as dateparser
 import re
 
-import alf.io
-from oneibl.one import ONE
+from one.alf.files import get_session_path
+from one.api import ONE
 from ibllib.misc import version
 import ibllib.time
 import ibllib.io.raw_data_loaders as raw
-from ibllib.io import flags, hashfile
+from ibllib.io import flags
+from iblutil.io import hashfile
 import ibllib.exceptions
 
-_logger = logging.getLogger('ibllib.alf')
+_logger = logging.getLogger('ibllib')
 EXCLUDED_EXTENSIONS = ['.flag', '.error', '.avi']
 REGISTRATION_GLOB_PATTERNS = ['alf/**/*.*',
                               'raw_behavior_data/**/_iblrig_*.*',
@@ -45,7 +46,7 @@ def register_dataset(file_list, one=None, created_by=None, repository=None, serv
     """
     Registers a set of files belonging to a session only on the server
     :param file_list: (list of pathlib.Path or pathlib.Path)
-    :param one: optional (oneibl.ONE), current one object, will create an instance if not provided
+    :param one: optional (one.api.One), current one object, will create an instance if not provided
     :param created_by: (string) name of user in Alyx (defaults to 'root')
     :param repository: optional: (string) name of the repository in Alyx
     :param server_only: optional: (bool) if True only creates on the Flatiron (defaults to False)
@@ -53,19 +54,18 @@ def register_dataset(file_list, one=None, created_by=None, repository=None, serv
     :param revisions: optional (list of strings): revision name (defaults to no revision)
     :param default: optional (bool) whether to set as default dataset (defaults to True)
     :param dry: (bool) False by default
-    :param verbose: (bool) logs
-    :param max_md5_size: (int) maximum file in bytes to compute md5 sum (always compute if Npne)
+    :param max_md5_size: (int) maximum file in bytes to compute md5 sum (always compute if None)
     defaults to None
     :return:
     """
     if created_by is None:
-        created_by = one._par.ALYX_LOGIN
+        created_by = getattr(one.alyx, 'user', None) or one._par.ALYX_LOGIN
     if file_list is None or file_list == '' or file_list == []:
         return
     elif not isinstance(file_list, list):
         file_list = [Path(file_list)]
 
-    assert len(set([alf.io.get_session_path(f) for f in file_list])) == 1
+    assert len(set([get_session_path(f) for f in file_list])) == 1
     assert all([Path(f).exists() for f in file_list])
     if versions is None:
         versions = version.ibllib()
@@ -74,7 +74,7 @@ def register_dataset(file_list, one=None, created_by=None, repository=None, serv
     assert isinstance(versions, list) and len(versions) == len(file_list)
 
     if revisions is None:
-        revisions = [None for _ in file_list]
+        revisions = [None] * len(file_list)
     else:
         if isinstance(revisions, str):
             revisions = [revisions for _ in file_list]
@@ -88,7 +88,7 @@ def register_dataset(file_list, one=None, created_by=None, repository=None, serv
     else:
         hashes = [hashfile.md5(p) for p in file_list]
 
-    session_path = alf.io.get_session_path(file_list[0])
+    session_path = get_session_path(file_list[0])
     # first register the file
     r = {'created_by': created_by,
          'path': session_path.relative_to((session_path.parents[2])).as_posix(),
@@ -102,8 +102,8 @@ def register_dataset(file_list, one=None, created_by=None, repository=None, serv
          'default': default}
     if not dry:
         if one is None:
-            one = ONE()
-        response = one.alyx.rest('register-file', 'create', data=r)
+            one = ONE(cache_rest=None)
+        response = one.alyx.rest('register-file', 'create', data=r, no_cache=True)
         for p in file_list:
             _logger.info(f"ALYX REGISTERED DATA: {p}")
         return response
@@ -122,7 +122,8 @@ def register_session_raw_data(session_path, one=None, overwrite=False, dry=False
     :return: Alyx response: dictionary of registered files
     """
     session_path = Path(session_path)
-    eid = one.eid_from_path(session_path, use_cache=False)  # needs to make sure we're up to date
+    one.alyx.clear_rest_cache()  # Ensure data are from database
+    eid = one.path2eid(session_path, query_type='remote')  # needs to make sure we're up to date
     # query the database for existing datasets on the session and allowed dataset types
     dsets = one.alyx.rest('datasets', 'list', session=eid)
     already_registered = [
@@ -152,12 +153,12 @@ class RegistrationClient:
     def __init__(self, one=None):
         self.one = one
         if not one:
-            self.one = ONE()
+            self.one = ONE(cache_rest=None)
         self.dtypes = self.one.alyx.rest('dataset-types', 'list')
         self.registration_patterns = [
             dt['filename_pattern'] for dt in self.dtypes if dt['filename_pattern']]
         self.file_extensions = [df['file_extension'] for df in
-                                self.one.alyx.rest('data-formats', 'list')]
+                                self.one.alyx.rest('data-formats', 'list', no_cache=True)]
 
     def create_sessions(self, root_data_folder, glob_pattern='**/create_me.flag', dry=False):
         """
@@ -213,7 +214,6 @@ class RegistrationClient:
 
         :param ses_path: path to the session
         :param file_list: bool. Set to False will only create the session and skip registration
-        :param repository_name: Optional, repository on which to register the data
         :return: Status string on error
         """
         if isinstance(ses_path, str):
@@ -225,7 +225,7 @@ class RegistrationClient:
             settings_json_file = list(ses_path.glob('**/_iblrig_taskSettings.raw*.json'))
             if not settings_json_file:
                 _logger.error(['could not find _iblrig_taskSettings.raw.json. Abort.'])
-                return
+                raise ValueError(f'_iblrig_taskSettings.raw.json not found in {ses_path} Abort.')
             _logger.warning([f'Settings found in a strange place: {settings_json_file}'])
         else:
             settings_json_file = settings_json_file[0]
@@ -238,7 +238,7 @@ class RegistrationClient:
             raise ibllib.exceptions.AlyxSubjectNotFound(md['SUBJECT_NAME'])
 
         # look for a session from the same subject, same number on the same day
-        session_id, session = self.one.search(subjects=subject['nickname'],
+        session_id, session = self.one.search(subject=subject['nickname'],
                                               date_range=md['SESSION_DATE'],
                                               number=md['SESSION_NUMBER'],
                                               details=True)
@@ -303,7 +303,7 @@ class RegistrationClient:
             self.one.alyx.rest('water-administrations', 'create', data=wa_)
         # at this point the session has been created. If create only, exit
         if not file_list:
-            return
+            return session
         # register all files that match the Alyx patterns, warn user when files are encountered
         rename_files_compatibility(ses_path, md['IBLRIG_VERSION_TAG'])
         F = []  # empty list whose keys will be relative paths and content filenames
@@ -344,6 +344,7 @@ class RegistrationClient:
               'versions': [version.ibllib() for _ in F]
               }
         self.one.alyx.post('/register-file', data=r_)
+        return session
 
 
 def _alyx_procedure_from_task(task_protocol):
